@@ -5,7 +5,7 @@ import json
 import datetime
 import subprocess
 import shutil
-import StringIO
+import io
 
 import sqlite3
 import yaml
@@ -73,7 +73,7 @@ class Worker(object):
             branch = task["branch_name"]
             commit = task["push_commit"]
 
-            self.output = StringIO.StringIO()
+            self.output = open("/tmp/%s" % push, "w+")
             self.commands = ["git checkout .", "git checkout %s" % branch, "git pull origin %s" % branch,
                              "git checkout %s" % commit, self._get_local_commands]
 
@@ -139,7 +139,8 @@ class Worker(object):
         self.application.enqueue(self._work)
 
     def _get_output(self):
-        output = self.output.getvalue()
+        self.output.seek(0, io.SEEK_SET)
+        output = self.output.readall()
         self.output.close()
         return output
 
